<?php
/**
 * NOTICE OF LICENSE.
 *
 * UNIT3D is open-sourced software licensed under the GNU Affero General Public License v3.0
 * The details is bundled with this project in the file LICENSE.txt.
 *
 * @project    UNIT3D
 *
 * @license    https://www.gnu.org/licenses/agpl-3.0.en.html/ GNU Affero General Public License v3.0
 * @author     HDVinnie
 */

namespace App\Models;

use App\Traits\Auditable;
use Illuminate\Database\Eloquent\Model;

/**
 * App\Models\Permission.
 *
 * @property int $id
 * @property int $forum_id
 * @property int $group_id
 * @property int $show_forum
 * @property int $read_topic
 * @property int $reply_topic
 * @property int $start_topic
 * @property-read \App\Models\Forum $forum
 * @property-read \App\Models\Group $group
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Permission newModelQuery()
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Permission newQuery()
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Permission query()
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Permission whereForumId($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Permission whereGroupId($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Permission whereId($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Permission whereReadTopic($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Permission whereReplyTopic($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Permission whereShowForum($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Permission whereStartTopic($value)
 * @mixin \Eloquent
 */
class Permission extends Model
{
    use Auditable;

    /**
     * Tells Laravel To Not Maintain The Timestamp Columns.
     *
     * @var bool
     */
    public $timestamps = false;

    /**
     * Belongs To A Group.
     *
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function group()
    {
        return $this->belongsTo(Group::class);
    }

    /**
     * Belongs To A Forum.
     *
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function forum()
    {
        return $this->belongsTo(Forum::class);
    }
}
